(->pattern-string x)(attempt)(attempt x)(attempt x & next)Returns result of first form that doesn't throw and doesn't return nil.
Returns result of first form that doesn't throw and doesn't return nil.
(branch? form)(categorize-arguments args)(children form)(compile-filter levels)(compile-key-pred keys)(compile-val-pred values)(deep-merge & maps)(env-data-reader env-var-name)(get* m k)(get* m k not-found)Like clojure.core/get except treats strings and keywords as interchangeable and not-found as the result if there is no entry or if the entry value is nil.
Like clojure.core/get except treats strings and keywords as interchangeable and not-found as the result if there is no entry *or* if the entry value is nil.
(get-in* m ks)(get-in* m ks not-found)Like clojure.core/get-in except built atop get*.
Like clojure.core/get-in except built atop get*.
(iterable? x)Is collection like or a single value?
Is collection like or a single value?
(level->int level)(logger->hierarchy logger)(parse-best-guess s)(parse-config config-string)(quietly & body)Execute the body and return nil if there was an error
Execute the body and return nil if there was an error
(split-pretty-printed s)(stringify-ident ident)(stringify-key k)(teed-writer source fork)(template text context)A simple string templating function that replaces {x.y.z} placeholders with values from the context.
A simple string templating function that replaces {x.y.z} placeholders with values from the context.
(try-parse-boolean s)(try-parse-number s)(unqualify m)(walk-seq form)(walk-unqualify form)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |