Clojure only.

datalogger.protos


LoggableDatacljprotocol

as-dataclj

(as-data x options)

Convert x into serializable (as json) data. Also handle any pruning of sensitive values (defined by options). Also produce a deterministic ordering of any unordered collections.

Convert x into serializable (as json) data.
Also handle any pruning of sensitive values (defined by options).
Also produce a deterministic ordering of any unordered collections.

cljdoc builds & hosts documentation for Clojure/Script libraries