(as-data x options)Convert x into serializable (as json) data. Also handle any pruning of sensitive values (defined by options). Also produce a deterministic ordering of any unordered collections.
Convert x into serializable (as json) data. Also handle any pruning of sensitive values (defined by options). Also produce a deterministic ordering of any unordered collections.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |